==============
InProcessQuery
==============

This namespace becomes available by calling `LazyFrame.collect(background=True)`.

.. currentmodule:: polars.lazyframe.in_process

.. autosummary::
   :toctree: api/

    InProcessQuery.cancel
    InProcessQuery.fetch
    InProcessQuery.fetch_blocking
